@@ -39,7 +39,7 @@ except ImportError:  # pragma: no cover
     pygments = False
     p_ver = (0, 0)
 
-RE_PYG_CODE = re.compile(r'^<(div|table)(\s*class=".*?")?\s*>')
+RE_PYG_CODE = re.compile(r'^<(div)(\s*class="(.*?)")?\s*>')
 CODE_WRAP = '<pre{}><code{}{}{}>{}</code></pre>'
 CODE_WRAP_ON_PRE = '<pre{}{}{}><code>{}</code></pre>'
 CLASS_ATTR = ' class="{}"'
@@ -52,7 +52,7 @@ DEFAULT_CONFIG = {
         'Default: True'
     ],
     'guess_lang': [
-        False,
+        0,
         "Automatic language detection - Default: False"
     ],
     'css_class': [
@@ -124,6 +124,16 @@ DEFAULT_CONFIG = {
         False,
         'If set to True, the language name used will be included as a class attached to the element. - Defaults: False'
     ],
+    'stripnl': [
+        True,
+        'Strips leading and trailing newlines from code blocks. This is Pygments default behavior. Setting this to '
+        'False disables this and will retain leading and trailing newlines. This has no affect on inline code. '
+        '- Defaults: True'
+    ],
+    'default_lang': [
+        '',
+        'The assumed highlight language of a code block when no language is set. - Default text'
+    ],
     '_enabled': [
         True,
         'Used internally to communicate if extension has been explicitly enabled - Default: False'
@@ -134,7 +144,12 @@ if pygments:
     class InlineHtmlFormatter(HtmlFormatter):
         """Format the code blocks."""
 
-        def wrap(self, source, outfile):
+        def _wrap_div(self, inner):
+            """Do not wrap with `div`."""
+
+            yield from inner
+
+        def wrap(self, source):
             """Overload wrap."""
 
             return self._wrap_code(source)
@@ -171,10 +186,7 @@ if pygments:
             # wrap the gutter number in the future with a highlight class.
             # The decision to do this has still not be made.
 
-            if p_ver >= (2, 7):
-                lnum = m.group(4) if not m.group(4).rstrip() else m.group(4)
-            else:  # pragma: no cover
-                lnum = m.group(4)
+            lnum = m.group(4) if not m.group(4).rstrip() else m.group(4)
 
             return (
                 m.group(1) +
@@ -200,12 +212,12 @@ if pygments:
                     line = self.RE_SPAN_NUMS.sub(self._format_custom_line, line)
                 yield t, line
 
-        def wrap(self, source, outfile):
+        def wrap(self, source):
             """Wrap the source code."""
 
             if self.linenos == 2 and self.pymdownx_inline:
                 source = self._wrap_customlinenums(source)
-            return HtmlFormatter.wrap(self, source, outfile)
+            return HtmlFormatter.wrap(self, source)
 
         def _wrap_tablelinenos(self, inner):
             """
@@ -228,7 +240,8 @@ class Highlight(object):
         noclasses=False, extend_pygments_lang=None, linenums=None, linenums_special=-1,
         linenums_style='table', linenums_class='linenums', language_prefix='language-',
         code_attr_on_pre=False, auto_title=False, auto_title_map=None, line_spans='',
-        anchor_linenums=False, line_anchors='', pygments_lang_class=False
+        anchor_linenums=False, line_anchors='', pygments_lang_class=False, stripnl=True,
+        default_lang=''
     ):
         """Initialize."""
 
@@ -247,6 +260,8 @@ class Highlight(object):
         self.line_anchors = line_anchors
         self.anchor_linenums = anchor_linenums
         self.pygments_lang_class = pygments_lang_class
+        self.stripnl = stripnl
+        self.default_lang = default_lang
 
         if self.anchor_linenums and not self.line_anchors:
             self.line_anchors = '__codelineno'
@@ -272,15 +287,15 @@ class Highlight(object):
 
         return self.extend_pygments_lang.get(language.lower(), (language, {}))
 
-    def get_lexer(self, src, language):
+    def get_lexer(self, src, language, inline, stripnl):
         """Get the Pygments lexer."""
 
         name = language
 
+        lexer_options = {'stripnl': stripnl}
         if language:
-            language, lexer_options = self.get_extended_language(language)
-        else:
-            lexer_options = {}
+            language, options = self.get_extended_language(language)
+            lexer_options.update(options)
 
         # Try and get lexer by the name given.
         try:
@@ -289,14 +304,14 @@ class Highlight(object):
             lexer = None
 
         if lexer is None:
-            if self.guess_lang:
+            if (self.guess_lang is True) or (self.guess_lang == 'inline' if inline else self.guess_lang == 'block'):
                 try:
-                    lexer = guess_lexer(src)
+                    lexer = guess_lexer(src, **lexer_options)
                     name = lexer.aliases[0]
                 except Exception:  # pragma: no cover
                     pass
         if lexer is None:
-            lexer = get_lexer_by_name('text')
+            lexer = get_lexer_by_name(self.default_lang or 'text', **lexer_options)
             name = lexer.aliases[0]
         return lexer, name
 
@@ -322,25 +337,39 @@ class Highlight(object):
             (self.linenums and linestart != 0) or
             (self.linenums is not False and linestart > 0)
         ) and not inline > 0
+        class_str = ''
+
+        if not language and self.default_lang:
+            language = self.default_lang
 
         # Convert with Pygments.
         if pygments and self.use_pygments:
+
+            if p_ver < (2, 12):  # pragma: no cover
+                raise RuntimeError('Pymdownx Highlight requires at least Pygments 2.12+ if enabling Pygments')
+
+            if inline:
+                stripnl = True
+            else:
+                stripnl = self.stripnl
+
             # Setup language lexer.
-            lexer, lang_name = self.get_lexer(src, language)
+            lexer, lang_name = self.get_lexer(src, language, inline, stripnl)
             if self.pygments_lang_class:
                 class_names.insert(0, self.language_prefix + lang_name)
             linenums = self.linenums_style if linenums_enabled else False
 
             if class_names:
-                css_class = ' {}'.format('' if not css_class else css_class)
-                css_class = ' '.join(class_names) + css_class
-                stripped = css_class.strip()
-
-                if not isinstance(linenums, str) or linenums != 'table':
+                if inline:
+                    css_class = ' {}'.format('' if not css_class else css_class)
+                    css_class = ' '.join(class_names) + css_class
+                    stripped = css_class.strip()
                     css_class = stripped
 
             id_str = ID_ATTR.format(id_value) if id_value else ''
 
+            lineno_id = id_value if id_value else str(code_block_count)
+
             if not attrs:
                 attr_str = ''
             else:
@@ -381,9 +410,9 @@ class Highlight(object):
                 hl_lines=hl_lines,
                 wrapcode=True,
                 filename=title if not inline else "",
-                linespans="{}-{:d}".format(self.line_spans, code_block_count) if self.line_spans and not inline else '',
+                linespans="{}-{}".format(self.line_spans, lineno_id) if self.line_spans and not inline else '',
                 lineanchors=(
-                    "{}-{:d}".format(self.line_anchors, code_block_count) if self.line_anchors and not inline else ""
+                    "{}-{}".format(self.line_anchors, lineno_id) if self.line_anchors and not inline else ""
                 ),
                 anchorlinenos=self.anchor_linenums if not inline else False
             )
@@ -398,7 +427,14 @@ class Highlight(object):
                 if m is not None:
                     end = m.end(0)
                     start = m.start(0)
-                    classes = ' ' + m.group(2).lstrip() if m.group(2) else ''
+                    if class_names:
+                        if m.group(2):
+                            classes = ' class="{} {}"'.format(' '.join(class_names), m.group(3).strip())
+                        else:
+                            classes = ' class="{}"'.format(' '.join(class_names))
+                    else:
+                        classes = ' ' + m.group(2).lstrip() if m.group(2) else ''
+
                     code = '{}<{}{}{}{}>{}'.format(code[:start], m.group(1), id_str, classes, attr_str, code[end:])
 
         elif inline:
@@ -454,7 +490,7 @@ class HighlightTreeprocessor(Treeprocessor):
         """Initialize."""
 
         self.ext = ext
-        super(HighlightTreeprocessor, self).__init__(md)
+        super().__init__(md)
 
     def code_unescape(self, text):
         """Unescape code."""
@@ -485,11 +521,13 @@ class HighlightTreeprocessor(Treeprocessor):
                     code_attr_on_pre=self.config['code_attr_on_pre'],
                     auto_title=self.config['auto_title'],
                     auto_title_map=self.config['auto_title_map'],
-                    pygments_lang_class=self.config['pygments_lang_class']
+                    pygments_lang_class=self.config['pygments_lang_class'],
+                    stripnl=self.config['stripnl'],
+                    default_lang=self.config['default_lang']
                 )
                 placeholder = self.md.htmlStash.store(
                     code.highlight(
-                        self.code_unescape(block[0].text),
+                        self.code_unescape(block[0].text).rstrip('\n'),
                         '',
                         self.config['css_class'],
                         code_block_count=self.ext.pygments_code_block
@@ -511,7 +549,7 @@ class HighlightExtension(Extension):
         """Initialize."""
 
         self.config = copy.deepcopy(DEFAULT_CONFIG)
-        super(HighlightExtension, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def get_pymdownx_highlight_settings(self):
         """Get the specified extension."""
@@ -524,7 +562,7 @@ class HighlightExtension(Extension):
         if target is None:
             target = {}
             config_clone = copy.deepcopy(DEFAULT_CONFIG)
-            for k, v in config_clone.items():
+            for k in config_clone.keys():
                 target[k] = config_clone[k][0]
 
         return target
