@@ -31,6 +31,47 @@ class TestHighlightGuess(util.MdCase):
         )
 
 
+class TestHighlightGuessBlock(util.MdCase):
+    """Test that highlighting works with guessing for block."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'guess_lang': "block"
+        }
+    }
+
+    def test_guess_block(self):
+        """Test guessing for block."""
+
+        self.check_markdown(
+            r'''
+            ```
+            import test
+            test.test()
+            ```
+            ''',
+            '''
+            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
+            </code></pre></div>
+            ''',
+            True
+        )
+
+    def test_no_guess_inline(self):
+        """Test inline code is not language guessed."""
+        self.check_markdown(
+            r'''
+            `int i = std::numeric_limits<int>::min();`
+            ''',
+            '''
+            <p><code>int i = std::numeric_limits&lt;int&gt;::min();</code></p>
+            ''',
+            True
+        )
+
+
 class TestHighlightAutoTitle(util.MdCase):
     """Test title cases."""
 
@@ -141,7 +182,7 @@ class TestNoClass(util.MdCase):
             <div><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
             </code></pre></div>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -159,7 +200,7 @@ class TestNoClass(util.MdCase):
             <div class="more"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
             </code></pre></div>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -174,11 +215,10 @@ class TestNoClass(util.MdCase):
             ```
             ''',
             r'''
-            <table class="more table"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span>
-            <span class="normal">2</span></pre></div></td><td class="code"><div class="more "><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div class="more"><table class="table"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span>
+            <span class="normal">2</span></pre></div></td><td class="code"><div><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
-            </code></pre></div>
-            </td></tr></table>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -208,7 +248,7 @@ class TestNoClassNoPygments(util.MdCase):
             r'''
             <pre><code class="language-python">import test
             test.test()</code></pre>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -237,7 +277,7 @@ class TestCustomLangPrefixNoPygments(util.MdCase):
             r'''
             <pre class="highlight"><code class="lang-python">import test
             test.test()</code></pre>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -295,6 +335,28 @@ class TestNoPygments(util.MdCase):
             True
         )
 
+    def test_no_pygments_extraneous_new_lines(self):
+        """Test that extraneous new lines are not included."""
+
+        self.check_markdown(
+            r'''
+            Test
+
+                import test
+                test.test()
+
+
+            Test
+            ''',
+            r'''
+            <p>Test</p>
+            <pre class="highlight"><code>import test
+            test.test()</code></pre>
+            <p>Test</p>
+            ''',
+            True
+        )
+
 
 class TestNoPygmentsCustomLineClass(util.MdCase):
     """Test no Pygments with custom line number class."""
@@ -323,8 +385,7 @@ class TestNoPygmentsCustomLineClass(util.MdCase):
             r'''
             <p>Text</p>
             <pre class="highlight"><code>import test
-            test.test()
-            </code></pre>
+            test.test()</code></pre>
             <p>Text</p>
             ''',
             True
@@ -420,7 +481,7 @@ class TestDisabledLinenums(util.MdCase):
             <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
             </code></pre></div>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -450,7 +511,7 @@ class TestDisabledLinenumsNoPygments(util.MdCase):
             <p><code>python linenums="1"
             import test
             test.test()</code></p>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -476,11 +537,10 @@ class TestGlobalLinenums(util.MdCase):
             ```
             ''',
             r'''
-            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span>
-            <span class="normal">2</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div class="highlight"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span>
+            <span class="normal">2</span></pre></div></td><td class="code"><div><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
-            </code></pre></div>
-            </td></tr></table>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -499,7 +559,7 @@ class TestGlobalLinenums(util.MdCase):
             <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             <span class="n">test</span><span class="o">.</span><span class="n">test</span><span class="p">()</span>
             </code></pre></div>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -600,3 +660,71 @@ class TestExtendedLang(util.MdCase):
             ''',  # noqa: E501
             True
         )
+
+
+class TestDefaultLang(util.MdCase):
+    """Test default block language cases."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences', 'pymdownx.inlinehilite']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'default_lang': 'python'
+        }
+    }
+
+    def test_default_block(self):
+        """Test that default language affects block, but not inline code."""
+
+        self.check_markdown(
+            '''
+            `import code`
+
+                import code
+
+            ```
+            import code
+            ```
+            ''',
+            '''
+            <p><code>import code</code></p>
+            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">code</span>
+            </code></pre></div>
+            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">code</span>
+            </code></pre></div>
+            ''',
+            True
+        )
+
+
+class TestDefaultLangInline(util.MdCase):
+    """Test default inline language cases."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences', 'pymdownx.inlinehilite']
+    extension_configs = {
+        'pymdownx.inlinehilite': {
+            'style_plain_text': 'python'
+        }
+    }
+
+    def test_default_inline(self):
+        """Test that default language affects block, but not inline code."""
+
+        self.check_markdown(
+            '''
+            `import code`
+
+                import code
+
+            ```
+            import code
+            ```
+            ''',
+            '''
+            <p><code class="highlight"><span class="kn">import</span> <span class="nn">code</span></code></p>
+            <div class="highlight"><pre><span></span><code>import code
+            </code></pre></div>
+            <div class="highlight"><pre><span></span><code>import code
+            </code></pre></div>
+            ''',
+            True
+        )
