@@ -104,14 +104,49 @@ class TestHighlightTitle(util.MdCase):
             ```
             ''',
             r'''
-            <table class="highlighttable"><tr><th colspan="2" class="filename"><div class="highlight"><span class="filename">My title</span></div></th></tr><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span class="gp">&gt;&gt;&gt; </span><span class="kn">import</span> <span class="nn">test</span>
-            </code></pre></div>
-            </td></tr></table>
+            <div class="highlight"><table class="highlighttable"><tr><th colspan="2" class="filename"><span class="filename">My title</span></th></tr><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div><pre><span></span><code><span class="gp">&gt;&gt;&gt; </span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
 
 
+class TestHighlightStrip(util.MdCase):
+    """Test Highlight's stripping of new lines."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {'pymdownx.highlight': {'stripnl': False}}
+
+    def test_no_stripnl(self):
+        """Test no stripping of leading and trailing new lines."""
+
+        self.check_markdown(
+            r'''
+            ```py
+
+            import foo
+
+
+            import bar
+
+
+
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code>
+            <span class="kn">import</span> <span class="nn">foo</span>
+
+
+            <span class="kn">import</span> <span class="nn">bar</span>
+
+
+            </code></pre></div>
+            ''',
+            True
+        )
+
+
 class TestHighlightAutoTitleOverride(util.MdCase):
     """Test title cases."""
 
@@ -235,9 +270,8 @@ class TestHighlightLineWrapsPymdownsTable(util.MdCase):
             ```
             ''',
             r'''
-            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span id="__my_span-0-2"><span class="kn">import</span> <span class="nn">test</span>
-            </span></code></pre></div>
-            </td></tr></table>
+            <div class="highlight"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div><pre><span></span><code><span id="__my_span-0-2"><span class="kn">import</span> <span class="nn">test</span>
+            </span></code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -320,9 +354,8 @@ class TestHighlightLineAnchorsPymdownsTable(util.MdCase):
             ```
             ''',
             r'''
-            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
-            </code></pre></div>
-            </td></tr></table>
+            <div class="highlight"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -355,6 +388,22 @@ class TestHighlightAnchorLinenumInline(util.MdCase):
             True
         )
 
+    def test_linespans_id(self):
+        """Test wrapping a line in line spans with an ID."""
+
+        self.check_markdown(
+            r'''
+            ```{.python #id linenums="2"}
+            import test
+            ```
+            ''',
+            r'''
+            <div id="id" class="highlight"><pre><span></span><code><a id="__codelineno-id-2" name="__codelineno-id-2"></a><a href="#__codelineno-id-2"><span class="linenos">2</span></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
 
 class TestHighlightAnchorLinenumsPymdownxInline(util.MdCase):
     """Test highlight line wraps."""
@@ -383,6 +432,22 @@ class TestHighlightAnchorLinenumsPymdownxInline(util.MdCase):
             True
         )
 
+    def test_linespans_id(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```{.python #id linenums="2"}
+            import test
+            ```
+            ''',
+            r'''
+            <div id="id" class="highlight"><pre><span></span><code><a id="__codelineno-id-2" name="__codelineno-id-2"></a><a href="#__codelineno-id-2"><span class="linenos" data-linenos="2 "></span></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
 
 class TestHighlightAnchorLinenumsPymdownsTable(util.MdCase):
     """Test highlight line wraps."""
@@ -405,9 +470,8 @@ class TestHighlightAnchorLinenumsPymdownsTable(util.MdCase):
             ```
             ''',
             r'''
-            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal"><a href="#__codelineno-0-2">2</a></span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><a id="__codelineno-0-2" name="__codelineno-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
-            </code></pre></div>
-            </td></tr></table>
+            <div class="highlight"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal"><a href="#__codelineno-0-2">2</a></span></pre></div></td><td class="code"><div><pre><span></span><code><a id="__codelineno-0-2" name="__codelineno-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -606,6 +670,22 @@ class TestSuperFencesClassesIdsAttrList(util.MdCase):
     extension = ['pymdownx.superfences', 'markdown.extensions.attr_list']
     extension_configs = {}
 
+    def test_attribute_lists_with_braces(self):
+        """Test attribute lists with braces."""
+
+        self.check_markdown(
+            R'''
+            ``` { .c data-copy="int main() { return 0; }" }
+            Try copying me for some C code
+            ```
+            ''',
+            R'''
+            <div class="highlight" data-copy="int main() { return 0; }"><pre><span></span><code><span class="n">Try</span><span class="w"> </span><span class="n">copying</span><span class="w"> </span><span class="n">me</span><span class="w"> </span><span class="k">for</span><span class="w"> </span><span class="n">some</span><span class="w"> </span><span class="n">C</span><span class="w"> </span><span class="n">code</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
     def test_classes(self):
         """Test extra classes."""
 
@@ -680,9 +760,8 @@ class TestSuperFencesClassesIdsAttrList(util.MdCase):
             ```
             ''',
             r'''
-            <table id="id" class="highlighttable" data-attr="test"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
-            </code></pre></div>
-            </td></tr></table>
+            <div id="id" class="highlight" data-attr="test"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div></td></tr></table></div>
             ''',  # noqa: E501
             True
         )
@@ -709,7 +788,7 @@ class TestSuperFencesClassesIdsAttrListNoPygments(util.MdCase):
             ''',
             r'''
             <pre class="highlight"><code class="language-python more">import test</code></pre>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
@@ -766,7 +845,7 @@ class TestSuperFencesClassesIdsAttrListNoPygmentsOnPre(util.MdCase):
             ''',
             r'''
             <pre class="language-python highlight more"><code>import test</code></pre>
-            ''',  # noqa: E501
+            ''',
             True
         )
 
